## $Id: interfaces.py 16993 2022-07-06 07:49:44Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab, IKofaObject,
    DisablePaymentGroupSource)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.lpng')

class ICustomSessionConfiguration(IKofaObject):
    """A session configuration object.
    """

    academic_session = schema.Choice(
        title = _(u'Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = True,
        )

    payment_disabled = schema.List(
        title = _(u'Payment disabled'),
        value_type = schema.Choice(
            source = DisablePaymentGroupSource(),
            ),
        required = False,
        defaultFactory=list,
        )

    def getSessionString():
        """Return the session string from the vocabulary.
        """

    interswitch_enabled = schema.Bool(
        title = _(u'Interswitch Collegepay integration enabled'),
        default = False,
        )

    interswitch_paydirect_enabled = schema.Bool(
        title = _(u'Interswitch Paydirect integration enabled'),
        default = False,
        )

    etranzact_webconnect_enabled = schema.Bool(
        title = _(u'Etranzact Webconnect integration enabled'),
        default = False,
        )

    etranzact_payoutlet_enabled = schema.Bool(
        title = _(u'Etranzact Payoutlet integration enabled'),
        default = False,
        )


    # Additional fees in custom package add here


    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order